.. image:: https://img.shields.io/pypi/v/flask-mdform.svg
    :target: https://pypi.python.org/pypi/flask-mdform
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/l/flask-mdform.svg
    :target: https://pypi.python.org/pypi/flask-mdform
    :alt: License

.. image:: https://img.shields.io/pypi/pyversions/flask-mdform.svg
    :target: https://pypi.python.org/pypi/flask-mdform
    :alt: Python Versions

.. image:: https://travis-ci.org/hgrecco/flask-mdform.svg?branch=master
    :target: https://travis-ci.org/hgrecco/flask-mdform
    :alt: CI

.. image:: https://coveralls.io/repos/github/hgrecco/flask-mdform/badge.svg?branch=master
    :target: https://coveralls.io/github/hgrecco/flask-mdform?branch=master
    :alt: Coverage

